#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 checkers
version:              0.5.6
visibility:           public
id:                   checkers-0.5.6-gEOFuGPzjLEkbFyxTzzHe
key:                  checkers-0.5.6-gEOFuGPzjLEkbFyxTzzHe
license:              BSD-3-Clause
copyright:            (c) 2008-2013 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott
stability:            experimental
homepage:             https://github.com/conal/checkers
synopsis:             Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.

    &#169; 2008-2013 by Conal Elliott; BSD3 license.

category:             Testing
abi:                  d2f82cd70433990a3c3f12342b1edab8
exposed:              True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils

hidden-modules:       Control.Monad.Extensions
import-dirs:          /usr/lib/ghc-8.10.5/site-local/checkers-0.5.6
library-dirs:         /usr/lib/ghc-8.10.5/site-local/checkers-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/checkers-0.5.6
hs-libraries:         HScheckers-0.5.6-gEOFuGPzjLEkbFyxTzzHe
depends:
    QuickCheck-2.14.2-AlBcjlnVb6HBYuJ8lOviFD array-0.5.4.0
    base-4.14.2.0 random-1.2.0-GZbCBA9NAlUBaVRSIi1HYu
    semigroupoids-5.3.5-CXCAmgAqO2AH1F4bh8bCjo

haddock-interfaces:   /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html:         /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

